import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DataKubernetesServiceConfig extends cdktf.TerraformMetaArguments {
    /**
     * metadata block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/service.html#metadata DataKubernetesService#metadata}
     *
     * @stability stable
     */
    readonly metadata: DataKubernetesServiceMetadata;
}
/**
 * @stability stable
 */
export declare class DataKubernetesServiceSpecPort extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    get nodePort(): number;
    /**
     * @stability stable
     */
    get port(): number;
    /**
     * @stability stable
     */
    get protocol(): string;
    /**
     * @stability stable
     */
    get targetPort(): string;
}
/**
 * @stability stable
 */
export declare class DataKubernetesServiceSpec extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get clusterIp(): string;
    /**
     * @stability stable
     */
    get externalIps(): string[];
    /**
     * @stability stable
     */
    get externalName(): string;
    /**
     * @stability stable
     */
    get externalTrafficPolicy(): string;
    /**
     * @stability stable
     */
    get healthCheckNodePort(): number;
    /**
     * @stability stable
     */
    get loadBalancerIp(): string;
    /**
     * @stability stable
     */
    get loadBalancerSourceRanges(): string[];
    /**
     * @stability stable
     */
    get port(): any;
    /**
     * @stability stable
     */
    get publishNotReadyAddresses(): any;
    /**
     * @stability stable
     */
    get selector(): any;
    /**
     * @stability stable
     */
    get sessionAffinity(): string;
    /**
     * @stability stable
     */
    get type(): string;
}
/**
 * @stability stable
 */
export declare class DataKubernetesServiceStatusLoadBalancerIngress extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get hostname(): string;
    /**
     * @stability stable
     */
    get ip(): string;
}
/**
 * @stability stable
 */
export declare class DataKubernetesServiceStatusLoadBalancer extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get ingress(): any;
}
/**
 * @stability stable
 */
export declare class DataKubernetesServiceStatus extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get loadBalancer(): any;
}
/**
 * @stability stable
 */
export interface DataKubernetesServiceMetadata {
    /**
     * An unstructured key value map stored with the service that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/service.html#annotations DataKubernetesService#annotations}
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the service.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/service.html#labels DataKubernetesService#labels}
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Name of the service, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/service.html#name DataKubernetesService#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Namespace defines the space within which name of the service must be unique.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/service.html#namespace DataKubernetesService#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
/**
 * @stability stable
 */
export declare class DataKubernetesServiceMetadataOutputReference extends cdktf.ComplexObject {
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    private _annotations?;
    /**
     * @stability stable
     */
    get annotations(): {
        [key: string]: string;
    } | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    set annotations(value: {
        [key: string]: string;
    } | cdktf.IResolvable | undefined);
    /**
     * @stability stable
     */
    resetAnnotations(): void;
    /**
     * @stability stable
     */
    get annotationsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    } | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    } | cdktf.IResolvable | undefined);
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string | undefined;
    /**
     * @stability stable
     */
    set name(value: string | undefined);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namespace?;
    /**
     * @stability stable
     */
    get namespace(): string | undefined;
    /**
     * @stability stable
     */
    set namespace(value: string | undefined);
    /**
     * @stability stable
     */
    resetNamespace(): void;
    /**
     * @stability stable
     */
    get namespaceInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/kubernetes/d/service.html kubernetes_service}.
 *
 * @stability stable
 */
export declare class DataKubernetesService extends cdktf.TerraformDataSource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/kubernetes/d/service.html kubernetes_service} Data Source.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: DataKubernetesServiceConfig);
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    spec(index: string): DataKubernetesServiceSpec;
    /**
     * @stability stable
     */
    status(index: string): DataKubernetesServiceStatus;
    private _metadata?;
    private __metadataOutput;
    /**
     * @stability stable
     */
    get metadata(): DataKubernetesServiceMetadataOutputReference;
    /**
     * @stability stable
     */
    putMetadata(value: DataKubernetesServiceMetadata): void;
    /**
     * @stability stable
     */
    get metadataInput(): DataKubernetesServiceMetadata | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
