import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface IngressConfig extends cdktf.TerraformMetaArguments {
    /**
     * Terraform will wait for the load balancer to have at least 1 endpoint before considering the resource created.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress.html#wait_for_load_balancer Ingress#wait_for_load_balancer}
     *
     * @stability stable
     */
    readonly waitForLoadBalancer?: boolean | cdktf.IResolvable;
    /**
     * metadata block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress.html#metadata Ingress#metadata}
     *
     * @stability stable
     */
    readonly metadata: IngressMetadata;
    /**
     * spec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress.html#spec Ingress#spec}
     *
     * @stability stable
     */
    readonly spec: IngressSpec;
}
/**
 * @stability stable
 */
export declare class IngressStatusLoadBalancerIngress extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get hostname(): string;
    /**
     * @stability stable
     */
    get ip(): string;
}
/**
 * @stability stable
 */
export declare class IngressStatusLoadBalancer extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get ingress(): any;
}
/**
 * @stability stable
 */
export declare class IngressStatus extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get loadBalancer(): any;
}
/**
 * @stability stable
 */
export interface IngressMetadata {
    /**
     * An unstructured key value map stored with the ingress that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress.html#annotations Ingress#annotations}
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided.
     *
     * This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress.html#generate_name Ingress#generate_name}
     *
     * @stability stable
     */
    readonly generateName?: string;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the ingress.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress.html#labels Ingress#labels}
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Name of the ingress, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress.html#name Ingress#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Namespace defines the space within which name of the ingress must be unique.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress.html#namespace Ingress#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
/**
 * @stability stable
 */
export declare class IngressMetadataOutputReference extends cdktf.ComplexObject {
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    private _annotations?;
    /**
     * @stability stable
     */
    get annotations(): {
        [key: string]: string;
    } | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    set annotations(value: {
        [key: string]: string;
    } | cdktf.IResolvable | undefined);
    /**
     * @stability stable
     */
    resetAnnotations(): void;
    /**
     * @stability stable
     */
    get annotationsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _generateName?;
    /**
     * @stability stable
     */
    get generateName(): string | undefined;
    /**
     * @stability stable
     */
    set generateName(value: string | undefined);
    /**
     * @stability stable
     */
    resetGenerateName(): void;
    /**
     * @stability stable
     */
    get generateNameInput(): string | undefined;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    } | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    } | cdktf.IResolvable | undefined);
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string | undefined;
    /**
     * @stability stable
     */
    set name(value: string | undefined);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namespace?;
    /**
     * @stability stable
     */
    get namespace(): string | undefined;
    /**
     * @stability stable
     */
    set namespace(value: string | undefined);
    /**
     * @stability stable
     */
    resetNamespace(): void;
    /**
     * @stability stable
     */
    get namespaceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface IngressSpecBackend {
    /**
     * Specifies the name of the referenced service.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress.html#service_name Ingress#service_name}
     *
     * @stability stable
     */
    readonly serviceName?: string;
    /**
     * Specifies the port of the referenced service.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress.html#service_port Ingress#service_port}
     *
     * @stability stable
     */
    readonly servicePort?: string;
}
/**
 * @stability stable
 */
export declare class IngressSpecBackendOutputReference extends cdktf.ComplexObject {
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    private _serviceName?;
    /**
     * @stability stable
     */
    get serviceName(): string | undefined;
    /**
     * @stability stable
     */
    set serviceName(value: string | undefined);
    /**
     * @stability stable
     */
    resetServiceName(): void;
    /**
     * @stability stable
     */
    get serviceNameInput(): string | undefined;
    private _servicePort?;
    /**
     * @stability stable
     */
    get servicePort(): string | undefined;
    /**
     * @stability stable
     */
    set servicePort(value: string | undefined);
    /**
     * @stability stable
     */
    resetServicePort(): void;
    /**
     * @stability stable
     */
    get servicePortInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface IngressSpecRuleHttpPathBackend {
    /**
     * Specifies the name of the referenced service.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress.html#service_name Ingress#service_name}
     *
     * @stability stable
     */
    readonly serviceName?: string;
    /**
     * Specifies the port of the referenced service.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress.html#service_port Ingress#service_port}
     *
     * @stability stable
     */
    readonly servicePort?: string;
}
/**
 * @stability stable
 */
export declare class IngressSpecRuleHttpPathBackendOutputReference extends cdktf.ComplexObject {
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    private _serviceName?;
    /**
     * @stability stable
     */
    get serviceName(): string | undefined;
    /**
     * @stability stable
     */
    set serviceName(value: string | undefined);
    /**
     * @stability stable
     */
    resetServiceName(): void;
    /**
     * @stability stable
     */
    get serviceNameInput(): string | undefined;
    private _servicePort?;
    /**
     * @stability stable
     */
    get servicePort(): string | undefined;
    /**
     * @stability stable
     */
    set servicePort(value: string | undefined);
    /**
     * @stability stable
     */
    resetServicePort(): void;
    /**
     * @stability stable
     */
    get servicePortInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface IngressSpecRuleHttpPath {
    /**
     * Path is matched against the path of an incoming request.
     *
     * Currently it can contain characters disallowed from the conventional "path" part of a URL as defined by RFC 3986. Paths must begin with a '/'. When unspecified, all paths from incoming requests are matched.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress.html#path Ingress#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * backend block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress.html#backend Ingress#backend}
     *
     * @stability stable
     */
    readonly backend?: IngressSpecRuleHttpPathBackend;
}
/**
 * @stability stable
 */
export interface IngressSpecRuleHttp {
    /**
     * path block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress.html#path Ingress#path}
     *
     * @stability stable
     */
    readonly path: IngressSpecRuleHttpPath[];
}
/**
 * @stability stable
 */
export declare class IngressSpecRuleHttpOutputReference extends cdktf.ComplexObject {
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    private _path?;
    /**
     * @stability stable
     */
    get path(): IngressSpecRuleHttpPath[];
    /**
     * @stability stable
     */
    set path(value: IngressSpecRuleHttpPath[]);
    /**
     * @stability stable
     */
    get pathInput(): IngressSpecRuleHttpPath[] | undefined;
}
/**
 * @stability stable
 */
export interface IngressSpecRule {
    /**
     * Host is the fully qualified domain name of a network host, as defined by RFC 3986.
     *
     * Note the following deviations from the "host" part of the URI as defined in RFC 3986: 1. IPs are not allowed. Currently an IngressRuleValue can only apply to
     * the IP in the Spec of the parent Ingress.
     * 2. The `:` delimiter is not respected because ports are not allowed.
     * Currently the port of an Ingress is implicitly :80 for http and
     * :443 for https.
     * Both these may change in the future. Incoming requests are matched against the host before the IngressRuleValue. If the host is unspecified, the Ingress routes all traffic based on the specified IngressRuleValue.
     *
     * Host can be "precise" which is a domain name without the terminating dot of a network host (e.g. "foo.bar.com") or "wildcard", which is a domain name prefixed with a single wildcard label (e.g. "*.foo.com"). The wildcard character '*' must appear by itself as the first DNS label and matches only a single label. You cannot have a wildcard label by itself (e.g. Host == "*"). Requests will be matched against the Host field in the following way: 1. If Host is precise, the request matches this rule if the http host header is equal to Host. 2. If Host is a wildcard, then the request matches this rule if the http host header is to equal to the suffix (removing the first label) of the wildcard rule.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress.html#host Ingress#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * http block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress.html#http Ingress#http}
     *
     * @stability stable
     */
    readonly http: IngressSpecRuleHttp;
}
/**
 * @stability stable
 */
export interface IngressSpecTls {
    /**
     * Hosts are a list of hosts included in the TLS certificate.
     *
     * The values in this list must match the name/s used in the tlsSecret. Defaults to the wildcard host setting for the loadbalancer controller fulfilling this Ingress, if left unspecified.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress.html#hosts Ingress#hosts}
     *
     * @stability stable
     */
    readonly hosts?: string[];
    /**
     * SecretName is the name of the secret used to terminate TLS traffic on port 443.
     *
     * Field is left optional to allow TLS routing based on SNI hostname alone. If the SNI host in a listener conflicts with the "Host" header field used by an IngressRule, the SNI host is used for termination and value of the Host header is used for routing.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress.html#secret_name Ingress#secret_name}
     *
     * @stability stable
     */
    readonly secretName?: string;
}
/**
 * @stability stable
 */
export interface IngressSpec {
    /**
     * IngressClassName is the name of the IngressClass cluster resource.
     *
     * The associated IngressClass defines which controller will implement the resource. This replaces the deprecated `kubernetes.io/ingress.class` annotation. For backwards compatibility, when that annotation is set, it must be given precedence over this field. The controller may emit a warning if the field and annotation have different values. Implementations of this API should ignore Ingresses without a class specified. An IngressClass resource may be marked as default, which can be used to set a default value for this field. For more information, refer to the IngressClass documentation.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress.html#ingress_class_name Ingress#ingress_class_name}
     *
     * @stability stable
     */
    readonly ingressClassName?: string;
    /**
     * backend block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress.html#backend Ingress#backend}
     *
     * @stability stable
     */
    readonly backend?: IngressSpecBackend;
    /**
     * rule block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress.html#rule Ingress#rule}
     *
     * @stability stable
     */
    readonly rule?: IngressSpecRule[];
    /**
     * tls block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress.html#tls Ingress#tls}
     *
     * @stability stable
     */
    readonly tls?: IngressSpecTls[];
}
/**
 * @stability stable
 */
export declare class IngressSpecOutputReference extends cdktf.ComplexObject {
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    private _ingressClassName?;
    /**
     * @stability stable
     */
    get ingressClassName(): string | undefined;
    /**
     * @stability stable
     */
    set ingressClassName(value: string | undefined);
    /**
     * @stability stable
     */
    resetIngressClassName(): void;
    /**
     * @stability stable
     */
    get ingressClassNameInput(): string | undefined;
    private _backend?;
    private __backendOutput;
    /**
     * @stability stable
     */
    get backend(): IngressSpecBackendOutputReference;
    /**
     * @stability stable
     */
    putBackend(value: IngressSpecBackend | undefined): void;
    /**
     * @stability stable
     */
    resetBackend(): void;
    /**
     * @stability stable
     */
    get backendInput(): IngressSpecBackend | undefined;
    private _rule?;
    /**
     * @stability stable
     */
    get rule(): IngressSpecRule[] | undefined;
    /**
     * @stability stable
     */
    set rule(value: IngressSpecRule[] | undefined);
    /**
     * @stability stable
     */
    resetRule(): void;
    /**
     * @stability stable
     */
    get ruleInput(): IngressSpecRule[] | undefined;
    private _tls?;
    /**
     * @stability stable
     */
    get tls(): IngressSpecTls[] | undefined;
    /**
     * @stability stable
     */
    set tls(value: IngressSpecTls[] | undefined);
    /**
     * @stability stable
     */
    resetTls(): void;
    /**
     * @stability stable
     */
    get tlsInput(): IngressSpecTls[] | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress.html kubernetes_ingress}.
 *
 * @stability stable
 */
export declare class Ingress extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/kubernetes/r/ingress.html kubernetes_ingress} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: IngressConfig);
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    status(index: string): IngressStatus;
    private _waitForLoadBalancer?;
    /**
     * @stability stable
     */
    get waitForLoadBalancer(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    set waitForLoadBalancer(value: boolean | cdktf.IResolvable | undefined);
    /**
     * @stability stable
     */
    resetWaitForLoadBalancer(): void;
    /**
     * @stability stable
     */
    get waitForLoadBalancerInput(): boolean | cdktf.IResolvable | undefined;
    private _metadata?;
    private __metadataOutput;
    /**
     * @stability stable
     */
    get metadata(): IngressMetadataOutputReference;
    /**
     * @stability stable
     */
    putMetadata(value: IngressMetadata): void;
    /**
     * @stability stable
     */
    get metadataInput(): IngressMetadata | undefined;
    private _spec?;
    private __specOutput;
    /**
     * @stability stable
     */
    get spec(): IngressSpecOutputReference;
    /**
     * @stability stable
     */
    putSpec(value: IngressSpec): void;
    /**
     * @stability stable
     */
    get specInput(): IngressSpec | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
