import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface PodSecurityPolicyConfig extends cdktf.TerraformMetaArguments {
    /**
     * metadata block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#metadata PodSecurityPolicy#metadata}
     *
     * @stability stable
     */
    readonly metadata: PodSecurityPolicyMetadata;
    /**
     * spec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#spec PodSecurityPolicy#spec}
     *
     * @stability stable
     */
    readonly spec: PodSecurityPolicySpec;
}
/**
 * @stability stable
 */
export interface PodSecurityPolicyMetadata {
    /**
     * An unstructured key value map stored with the podsecuritypolicy that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#annotations PodSecurityPolicy#annotations}
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the podsecuritypolicy.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#labels PodSecurityPolicy#labels}
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Name of the podsecuritypolicy, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#name PodSecurityPolicy#name}
     *
     * @stability stable
     */
    readonly name?: string;
}
/**
 * @stability stable
 */
export declare class PodSecurityPolicyMetadataOutputReference extends cdktf.ComplexObject {
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    private _annotations?;
    /**
     * @stability stable
     */
    get annotations(): {
        [key: string]: string;
    } | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    set annotations(value: {
        [key: string]: string;
    } | cdktf.IResolvable | undefined);
    /**
     * @stability stable
     */
    resetAnnotations(): void;
    /**
     * @stability stable
     */
    get annotationsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    } | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    } | cdktf.IResolvable | undefined);
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string | undefined;
    /**
     * @stability stable
     */
    set name(value: string | undefined);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface PodSecurityPolicySpecAllowedFlexVolumes {
    /**
     * driver is the name of the Flexvolume driver.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#driver PodSecurityPolicy#driver}
     *
     * @stability stable
     */
    readonly driver: string;
}
/**
 * @stability stable
 */
export interface PodSecurityPolicySpecAllowedHostPaths {
    /**
     * pathPrefix is the path prefix that the host volume must match.
     *
     * It does not support `*`. Trailing slashes are trimmed when validating the path prefix with a host path.
     *
     * Examples: `/foo` would allow `/foo`, `/foo/` and `/foo/bar` `/foo` would not allow `/food` or `/etc/foo`
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#path_prefix PodSecurityPolicy#path_prefix}
     *
     * @stability stable
     */
    readonly pathPrefix: string;
    /**
     * when set to true, will allow host volumes matching the pathPrefix only if all volume mounts are readOnly.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#read_only PodSecurityPolicy#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
}
/**
 * @stability stable
 */
export interface PodSecurityPolicySpecFsGroupRange {
    /**
     * max is the end of the range, inclusive.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#max PodSecurityPolicy#max}
     *
     * @stability stable
     */
    readonly max: number;
    /**
     * min is the start of the range, inclusive.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#min PodSecurityPolicy#min}
     *
     * @stability stable
     */
    readonly min: number;
}
/**
 * @stability stable
 */
export interface PodSecurityPolicySpecFsGroup {
    /**
     * rule is the strategy that will dictate what FSGroup is used in the SecurityContext.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#rule PodSecurityPolicy#rule}
     *
     * @stability stable
     */
    readonly rule: string;
    /**
     * range block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#range PodSecurityPolicy#range}
     *
     * @stability stable
     */
    readonly range?: PodSecurityPolicySpecFsGroupRange[];
}
/**
 * @stability stable
 */
export declare class PodSecurityPolicySpecFsGroupOutputReference extends cdktf.ComplexObject {
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    private _rule?;
    /**
     * @stability stable
     */
    get rule(): string;
    /**
     * @stability stable
     */
    set rule(value: string);
    /**
     * @stability stable
     */
    get ruleInput(): string | undefined;
    private _range?;
    /**
     * @stability stable
     */
    get range(): PodSecurityPolicySpecFsGroupRange[] | undefined;
    /**
     * @stability stable
     */
    set range(value: PodSecurityPolicySpecFsGroupRange[] | undefined);
    /**
     * @stability stable
     */
    resetRange(): void;
    /**
     * @stability stable
     */
    get rangeInput(): PodSecurityPolicySpecFsGroupRange[] | undefined;
}
/**
 * @stability stable
 */
export interface PodSecurityPolicySpecHostPorts {
    /**
     * max is the end of the range, inclusive.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#max PodSecurityPolicy#max}
     *
     * @stability stable
     */
    readonly max: number;
    /**
     * min is the start of the range, inclusive.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#min PodSecurityPolicy#min}
     *
     * @stability stable
     */
    readonly min: number;
}
/**
 * @stability stable
 */
export interface PodSecurityPolicySpecRunAsGroupRange {
    /**
     * max is the end of the range, inclusive.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#max PodSecurityPolicy#max}
     *
     * @stability stable
     */
    readonly max: number;
    /**
     * min is the start of the range, inclusive.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#min PodSecurityPolicy#min}
     *
     * @stability stable
     */
    readonly min: number;
}
/**
 * @stability stable
 */
export interface PodSecurityPolicySpecRunAsGroup {
    /**
     * rule is the strategy that will dictate the allowable RunAsGroup values that may be set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#rule PodSecurityPolicy#rule}
     *
     * @stability stable
     */
    readonly rule: string;
    /**
     * range block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#range PodSecurityPolicy#range}
     *
     * @stability stable
     */
    readonly range?: PodSecurityPolicySpecRunAsGroupRange[];
}
/**
 * @stability stable
 */
export declare class PodSecurityPolicySpecRunAsGroupOutputReference extends cdktf.ComplexObject {
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    private _rule?;
    /**
     * @stability stable
     */
    get rule(): string;
    /**
     * @stability stable
     */
    set rule(value: string);
    /**
     * @stability stable
     */
    get ruleInput(): string | undefined;
    private _range?;
    /**
     * @stability stable
     */
    get range(): PodSecurityPolicySpecRunAsGroupRange[] | undefined;
    /**
     * @stability stable
     */
    set range(value: PodSecurityPolicySpecRunAsGroupRange[] | undefined);
    /**
     * @stability stable
     */
    resetRange(): void;
    /**
     * @stability stable
     */
    get rangeInput(): PodSecurityPolicySpecRunAsGroupRange[] | undefined;
}
/**
 * @stability stable
 */
export interface PodSecurityPolicySpecRunAsUserRange {
    /**
     * max is the end of the range, inclusive.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#max PodSecurityPolicy#max}
     *
     * @stability stable
     */
    readonly max: number;
    /**
     * min is the start of the range, inclusive.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#min PodSecurityPolicy#min}
     *
     * @stability stable
     */
    readonly min: number;
}
/**
 * @stability stable
 */
export interface PodSecurityPolicySpecRunAsUser {
    /**
     * rule is the strategy that will dictate the allowable RunAsUser values that may be set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#rule PodSecurityPolicy#rule}
     *
     * @stability stable
     */
    readonly rule: string;
    /**
     * range block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#range PodSecurityPolicy#range}
     *
     * @stability stable
     */
    readonly range?: PodSecurityPolicySpecRunAsUserRange[];
}
/**
 * @stability stable
 */
export declare class PodSecurityPolicySpecRunAsUserOutputReference extends cdktf.ComplexObject {
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    private _rule?;
    /**
     * @stability stable
     */
    get rule(): string;
    /**
     * @stability stable
     */
    set rule(value: string);
    /**
     * @stability stable
     */
    get ruleInput(): string | undefined;
    private _range?;
    /**
     * @stability stable
     */
    get range(): PodSecurityPolicySpecRunAsUserRange[] | undefined;
    /**
     * @stability stable
     */
    set range(value: PodSecurityPolicySpecRunAsUserRange[] | undefined);
    /**
     * @stability stable
     */
    resetRange(): void;
    /**
     * @stability stable
     */
    get rangeInput(): PodSecurityPolicySpecRunAsUserRange[] | undefined;
}
/**
 * @stability stable
 */
export interface PodSecurityPolicySpecSeLinuxSeLinuxOptions {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#level PodSecurityPolicy#level}.
     *
     * @stability stable
     */
    readonly level: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#role PodSecurityPolicy#role}.
     *
     * @stability stable
     */
    readonly role: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#type PodSecurityPolicy#type}.
     *
     * @stability stable
     */
    readonly type: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#user PodSecurityPolicy#user}.
     *
     * @stability stable
     */
    readonly user: string;
}
/**
 * @stability stable
 */
export interface PodSecurityPolicySpecSeLinux {
    /**
     * rule is the strategy that will dictate the allowable labels that may be set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#rule PodSecurityPolicy#rule}
     *
     * @stability stable
     */
    readonly rule: string;
    /**
     * se_linux_options block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#se_linux_options PodSecurityPolicy#se_linux_options}
     *
     * @stability stable
     */
    readonly seLinuxOptions?: PodSecurityPolicySpecSeLinuxSeLinuxOptions[];
}
/**
 * @stability stable
 */
export declare class PodSecurityPolicySpecSeLinuxOutputReference extends cdktf.ComplexObject {
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    private _rule?;
    /**
     * @stability stable
     */
    get rule(): string;
    /**
     * @stability stable
     */
    set rule(value: string);
    /**
     * @stability stable
     */
    get ruleInput(): string | undefined;
    private _seLinuxOptions?;
    /**
     * @stability stable
     */
    get seLinuxOptions(): PodSecurityPolicySpecSeLinuxSeLinuxOptions[] | undefined;
    /**
     * @stability stable
     */
    set seLinuxOptions(value: PodSecurityPolicySpecSeLinuxSeLinuxOptions[] | undefined);
    /**
     * @stability stable
     */
    resetSeLinuxOptions(): void;
    /**
     * @stability stable
     */
    get seLinuxOptionsInput(): PodSecurityPolicySpecSeLinuxSeLinuxOptions[] | undefined;
}
/**
 * @stability stable
 */
export interface PodSecurityPolicySpecSupplementalGroupsRange {
    /**
     * max is the end of the range, inclusive.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#max PodSecurityPolicy#max}
     *
     * @stability stable
     */
    readonly max: number;
    /**
     * min is the start of the range, inclusive.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#min PodSecurityPolicy#min}
     *
     * @stability stable
     */
    readonly min: number;
}
/**
 * @stability stable
 */
export interface PodSecurityPolicySpecSupplementalGroups {
    /**
     * rule is the strategy that will dictate what supplemental groups is used in the SecurityContext.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#rule PodSecurityPolicy#rule}
     *
     * @stability stable
     */
    readonly rule: string;
    /**
     * range block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#range PodSecurityPolicy#range}
     *
     * @stability stable
     */
    readonly range?: PodSecurityPolicySpecSupplementalGroupsRange[];
}
/**
 * @stability stable
 */
export declare class PodSecurityPolicySpecSupplementalGroupsOutputReference extends cdktf.ComplexObject {
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    private _rule?;
    /**
     * @stability stable
     */
    get rule(): string;
    /**
     * @stability stable
     */
    set rule(value: string);
    /**
     * @stability stable
     */
    get ruleInput(): string | undefined;
    private _range?;
    /**
     * @stability stable
     */
    get range(): PodSecurityPolicySpecSupplementalGroupsRange[] | undefined;
    /**
     * @stability stable
     */
    set range(value: PodSecurityPolicySpecSupplementalGroupsRange[] | undefined);
    /**
     * @stability stable
     */
    resetRange(): void;
    /**
     * @stability stable
     */
    get rangeInput(): PodSecurityPolicySpecSupplementalGroupsRange[] | undefined;
}
/**
 * @stability stable
 */
export interface PodSecurityPolicySpec {
    /**
     * allowPrivilegeEscalation determines if a pod can request to allow privilege escalation. If unspecified, defaults to true.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#allow_privilege_escalation PodSecurityPolicy#allow_privilege_escalation}
     *
     * @stability stable
     */
    readonly allowPrivilegeEscalation?: boolean | cdktf.IResolvable;
    /**
     * allowedCapabilities is a list of capabilities that can be requested to add to the container.
     *
     * Capabilities in this field may be added at the pod author's discretion. You must not list a capability in both allowedCapabilities and requiredDropCapabilities.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#allowed_capabilities PodSecurityPolicy#allowed_capabilities}
     *
     * @stability stable
     */
    readonly allowedCapabilities?: string[];
    /**
     * AllowedProcMountTypes is an allowlist of allowed ProcMountTypes.
     *
     * Empty or nil indicates that only the DefaultProcMountType may be used. This requires the ProcMountType feature flag to be enabled.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#allowed_proc_mount_types PodSecurityPolicy#allowed_proc_mount_types}
     *
     * @stability stable
     */
    readonly allowedProcMountTypes?: string[];
    /**
     * allowedUnsafeSysctls is a list of explicitly allowed unsafe sysctls, defaults to none.
     *
     * Each entry is either a plain sysctl name or ends in "*" in which case it is considered as a prefix of allowed sysctls. Single * means all unsafe sysctls are allowed. Kubelet has to allowlist all allowed unsafe sysctls explicitly to avoid rejection.
     *
     * Examples: e.g. "foo/*" allows "foo/bar", "foo/baz", etc. e.g. "foo.*" allows "foo.bar", "foo.baz", etc.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#allowed_unsafe_sysctls PodSecurityPolicy#allowed_unsafe_sysctls}
     *
     * @stability stable
     */
    readonly allowedUnsafeSysctls?: string[];
    /**
     * defaultAddCapabilities is the default set of capabilities that will be added to the container unless the pod spec specifically drops the capability.
     *
     * You may not list a capability in both defaultAddCapabilities and requiredDropCapabilities. Capabilities added here are implicitly allowed, and need not be included in the allowedCapabilities list.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#default_add_capabilities PodSecurityPolicy#default_add_capabilities}
     *
     * @stability stable
     */
    readonly defaultAddCapabilities?: string[];
    /**
     * defaultAllowPrivilegeEscalation controls the default setting for whether a process can gain more privileges than its parent process.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#default_allow_privilege_escalation PodSecurityPolicy#default_allow_privilege_escalation}
     *
     * @stability stable
     */
    readonly defaultAllowPrivilegeEscalation?: boolean | cdktf.IResolvable;
    /**
     * forbiddenSysctls is a list of explicitly forbidden sysctls, defaults to none.
     *
     * Each entry is either a plain sysctl name or ends in "*" in which case it is considered as a prefix of forbidden sysctls. Single * means all sysctls are forbidden.
     *
     * Examples: e.g. "foo/*" forbids "foo/bar", "foo/baz", etc. e.g. "foo.*" forbids "foo.bar", "foo.baz", etc.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#forbidden_sysctls PodSecurityPolicy#forbidden_sysctls}
     *
     * @stability stable
     */
    readonly forbiddenSysctls?: string[];
    /**
     * hostIPC determines if the policy allows the use of HostIPC in the pod spec.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#host_ipc PodSecurityPolicy#host_ipc}
     *
     * @stability stable
     */
    readonly hostIpc?: boolean | cdktf.IResolvable;
    /**
     * hostNetwork determines if the policy allows the use of HostNetwork in the pod spec.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#host_network PodSecurityPolicy#host_network}
     *
     * @stability stable
     */
    readonly hostNetwork?: boolean | cdktf.IResolvable;
    /**
     * hostPID determines if the policy allows the use of HostPID in the pod spec.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#host_pid PodSecurityPolicy#host_pid}
     *
     * @stability stable
     */
    readonly hostPid?: boolean | cdktf.IResolvable;
    /**
     * privileged determines if a pod can request to be run as privileged.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#privileged PodSecurityPolicy#privileged}
     *
     * @stability stable
     */
    readonly privileged?: boolean | cdktf.IResolvable;
    /**
     * readOnlyRootFilesystem when set to true will force containers to run with a read only root file system.
     *
     * If the container specifically requests to run with a non-read only root file system the PSP should deny the pod. If set to false the container may run with a read only root file system if it wishes but it will not be forced to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#read_only_root_filesystem PodSecurityPolicy#read_only_root_filesystem}
     *
     * @stability stable
     */
    readonly readOnlyRootFilesystem?: boolean | cdktf.IResolvable;
    /**
     * requiredDropCapabilities are the capabilities that will be dropped from the container.
     *
     * These are required to be dropped and cannot be added.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#required_drop_capabilities PodSecurityPolicy#required_drop_capabilities}
     *
     * @stability stable
     */
    readonly requiredDropCapabilities?: string[];
    /**
     * volumes is an allowlist of volume plugins.
     *
     * Empty indicates that no volumes may be used. To allow all volumes you may use '*'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#volumes PodSecurityPolicy#volumes}
     *
     * @stability stable
     */
    readonly volumes?: string[];
    /**
     * allowed_flex_volumes block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#allowed_flex_volumes PodSecurityPolicy#allowed_flex_volumes}
     *
     * @stability stable
     */
    readonly allowedFlexVolumes?: PodSecurityPolicySpecAllowedFlexVolumes[];
    /**
     * allowed_host_paths block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#allowed_host_paths PodSecurityPolicy#allowed_host_paths}
     *
     * @stability stable
     */
    readonly allowedHostPaths?: PodSecurityPolicySpecAllowedHostPaths[];
    /**
     * fs_group block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#fs_group PodSecurityPolicy#fs_group}
     *
     * @stability stable
     */
    readonly fsGroup: PodSecurityPolicySpecFsGroup;
    /**
     * host_ports block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#host_ports PodSecurityPolicy#host_ports}
     *
     * @stability stable
     */
    readonly hostPorts?: PodSecurityPolicySpecHostPorts[];
    /**
     * run_as_group block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#run_as_group PodSecurityPolicy#run_as_group}
     *
     * @stability stable
     */
    readonly runAsGroup?: PodSecurityPolicySpecRunAsGroup;
    /**
     * run_as_user block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#run_as_user PodSecurityPolicy#run_as_user}
     *
     * @stability stable
     */
    readonly runAsUser: PodSecurityPolicySpecRunAsUser;
    /**
     * se_linux block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#se_linux PodSecurityPolicy#se_linux}
     *
     * @stability stable
     */
    readonly seLinux?: PodSecurityPolicySpecSeLinux;
    /**
     * supplemental_groups block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#supplemental_groups PodSecurityPolicy#supplemental_groups}
     *
     * @stability stable
     */
    readonly supplementalGroups: PodSecurityPolicySpecSupplementalGroups;
}
/**
 * @stability stable
 */
export declare class PodSecurityPolicySpecOutputReference extends cdktf.ComplexObject {
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    private _allowPrivilegeEscalation?;
    /**
     * @stability stable
     */
    get allowPrivilegeEscalation(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    set allowPrivilegeEscalation(value: boolean | cdktf.IResolvable | undefined);
    /**
     * @stability stable
     */
    resetAllowPrivilegeEscalation(): void;
    /**
     * @stability stable
     */
    get allowPrivilegeEscalationInput(): boolean | cdktf.IResolvable | undefined;
    private _allowedCapabilities?;
    /**
     * @stability stable
     */
    get allowedCapabilities(): string[] | undefined;
    /**
     * @stability stable
     */
    set allowedCapabilities(value: string[] | undefined);
    /**
     * @stability stable
     */
    resetAllowedCapabilities(): void;
    /**
     * @stability stable
     */
    get allowedCapabilitiesInput(): string[] | undefined;
    private _allowedProcMountTypes?;
    /**
     * @stability stable
     */
    get allowedProcMountTypes(): string[] | undefined;
    /**
     * @stability stable
     */
    set allowedProcMountTypes(value: string[] | undefined);
    /**
     * @stability stable
     */
    resetAllowedProcMountTypes(): void;
    /**
     * @stability stable
     */
    get allowedProcMountTypesInput(): string[] | undefined;
    private _allowedUnsafeSysctls?;
    /**
     * @stability stable
     */
    get allowedUnsafeSysctls(): string[] | undefined;
    /**
     * @stability stable
     */
    set allowedUnsafeSysctls(value: string[] | undefined);
    /**
     * @stability stable
     */
    resetAllowedUnsafeSysctls(): void;
    /**
     * @stability stable
     */
    get allowedUnsafeSysctlsInput(): string[] | undefined;
    private _defaultAddCapabilities?;
    /**
     * @stability stable
     */
    get defaultAddCapabilities(): string[] | undefined;
    /**
     * @stability stable
     */
    set defaultAddCapabilities(value: string[] | undefined);
    /**
     * @stability stable
     */
    resetDefaultAddCapabilities(): void;
    /**
     * @stability stable
     */
    get defaultAddCapabilitiesInput(): string[] | undefined;
    private _defaultAllowPrivilegeEscalation?;
    /**
     * @stability stable
     */
    get defaultAllowPrivilegeEscalation(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    set defaultAllowPrivilegeEscalation(value: boolean | cdktf.IResolvable | undefined);
    /**
     * @stability stable
     */
    resetDefaultAllowPrivilegeEscalation(): void;
    /**
     * @stability stable
     */
    get defaultAllowPrivilegeEscalationInput(): boolean | cdktf.IResolvable | undefined;
    private _forbiddenSysctls?;
    /**
     * @stability stable
     */
    get forbiddenSysctls(): string[] | undefined;
    /**
     * @stability stable
     */
    set forbiddenSysctls(value: string[] | undefined);
    /**
     * @stability stable
     */
    resetForbiddenSysctls(): void;
    /**
     * @stability stable
     */
    get forbiddenSysctlsInput(): string[] | undefined;
    private _hostIpc?;
    /**
     * @stability stable
     */
    get hostIpc(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    set hostIpc(value: boolean | cdktf.IResolvable | undefined);
    /**
     * @stability stable
     */
    resetHostIpc(): void;
    /**
     * @stability stable
     */
    get hostIpcInput(): boolean | cdktf.IResolvable | undefined;
    private _hostNetwork?;
    /**
     * @stability stable
     */
    get hostNetwork(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    set hostNetwork(value: boolean | cdktf.IResolvable | undefined);
    /**
     * @stability stable
     */
    resetHostNetwork(): void;
    /**
     * @stability stable
     */
    get hostNetworkInput(): boolean | cdktf.IResolvable | undefined;
    private _hostPid?;
    /**
     * @stability stable
     */
    get hostPid(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    set hostPid(value: boolean | cdktf.IResolvable | undefined);
    /**
     * @stability stable
     */
    resetHostPid(): void;
    /**
     * @stability stable
     */
    get hostPidInput(): boolean | cdktf.IResolvable | undefined;
    private _privileged?;
    /**
     * @stability stable
     */
    get privileged(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    set privileged(value: boolean | cdktf.IResolvable | undefined);
    /**
     * @stability stable
     */
    resetPrivileged(): void;
    /**
     * @stability stable
     */
    get privilegedInput(): boolean | cdktf.IResolvable | undefined;
    private _readOnlyRootFilesystem?;
    /**
     * @stability stable
     */
    get readOnlyRootFilesystem(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    set readOnlyRootFilesystem(value: boolean | cdktf.IResolvable | undefined);
    /**
     * @stability stable
     */
    resetReadOnlyRootFilesystem(): void;
    /**
     * @stability stable
     */
    get readOnlyRootFilesystemInput(): boolean | cdktf.IResolvable | undefined;
    private _requiredDropCapabilities?;
    /**
     * @stability stable
     */
    get requiredDropCapabilities(): string[] | undefined;
    /**
     * @stability stable
     */
    set requiredDropCapabilities(value: string[] | undefined);
    /**
     * @stability stable
     */
    resetRequiredDropCapabilities(): void;
    /**
     * @stability stable
     */
    get requiredDropCapabilitiesInput(): string[] | undefined;
    private _volumes?;
    /**
     * @stability stable
     */
    get volumes(): string[] | undefined;
    /**
     * @stability stable
     */
    set volumes(value: string[] | undefined);
    /**
     * @stability stable
     */
    resetVolumes(): void;
    /**
     * @stability stable
     */
    get volumesInput(): string[] | undefined;
    private _allowedFlexVolumes?;
    /**
     * @stability stable
     */
    get allowedFlexVolumes(): PodSecurityPolicySpecAllowedFlexVolumes[] | undefined;
    /**
     * @stability stable
     */
    set allowedFlexVolumes(value: PodSecurityPolicySpecAllowedFlexVolumes[] | undefined);
    /**
     * @stability stable
     */
    resetAllowedFlexVolumes(): void;
    /**
     * @stability stable
     */
    get allowedFlexVolumesInput(): PodSecurityPolicySpecAllowedFlexVolumes[] | undefined;
    private _allowedHostPaths?;
    /**
     * @stability stable
     */
    get allowedHostPaths(): PodSecurityPolicySpecAllowedHostPaths[] | undefined;
    /**
     * @stability stable
     */
    set allowedHostPaths(value: PodSecurityPolicySpecAllowedHostPaths[] | undefined);
    /**
     * @stability stable
     */
    resetAllowedHostPaths(): void;
    /**
     * @stability stable
     */
    get allowedHostPathsInput(): PodSecurityPolicySpecAllowedHostPaths[] | undefined;
    private _fsGroup?;
    private __fsGroupOutput;
    /**
     * @stability stable
     */
    get fsGroup(): PodSecurityPolicySpecFsGroupOutputReference;
    /**
     * @stability stable
     */
    putFsGroup(value: PodSecurityPolicySpecFsGroup): void;
    /**
     * @stability stable
     */
    get fsGroupInput(): PodSecurityPolicySpecFsGroup | undefined;
    private _hostPorts?;
    /**
     * @stability stable
     */
    get hostPorts(): PodSecurityPolicySpecHostPorts[] | undefined;
    /**
     * @stability stable
     */
    set hostPorts(value: PodSecurityPolicySpecHostPorts[] | undefined);
    /**
     * @stability stable
     */
    resetHostPorts(): void;
    /**
     * @stability stable
     */
    get hostPortsInput(): PodSecurityPolicySpecHostPorts[] | undefined;
    private _runAsGroup?;
    private __runAsGroupOutput;
    /**
     * @stability stable
     */
    get runAsGroup(): PodSecurityPolicySpecRunAsGroupOutputReference;
    /**
     * @stability stable
     */
    putRunAsGroup(value: PodSecurityPolicySpecRunAsGroup | undefined): void;
    /**
     * @stability stable
     */
    resetRunAsGroup(): void;
    /**
     * @stability stable
     */
    get runAsGroupInput(): PodSecurityPolicySpecRunAsGroup | undefined;
    private _runAsUser?;
    private __runAsUserOutput;
    /**
     * @stability stable
     */
    get runAsUser(): PodSecurityPolicySpecRunAsUserOutputReference;
    /**
     * @stability stable
     */
    putRunAsUser(value: PodSecurityPolicySpecRunAsUser): void;
    /**
     * @stability stable
     */
    get runAsUserInput(): PodSecurityPolicySpecRunAsUser | undefined;
    private _seLinux?;
    private __seLinuxOutput;
    /**
     * @stability stable
     */
    get seLinux(): PodSecurityPolicySpecSeLinuxOutputReference;
    /**
     * @stability stable
     */
    putSeLinux(value: PodSecurityPolicySpecSeLinux | undefined): void;
    /**
     * @stability stable
     */
    resetSeLinux(): void;
    /**
     * @stability stable
     */
    get seLinuxInput(): PodSecurityPolicySpecSeLinux | undefined;
    private _supplementalGroups?;
    private __supplementalGroupsOutput;
    /**
     * @stability stable
     */
    get supplementalGroups(): PodSecurityPolicySpecSupplementalGroupsOutputReference;
    /**
     * @stability stable
     */
    putSupplementalGroups(value: PodSecurityPolicySpecSupplementalGroups): void;
    /**
     * @stability stable
     */
    get supplementalGroupsInput(): PodSecurityPolicySpecSupplementalGroups | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html kubernetes_pod_security_policy}.
 *
 * @stability stable
 */
export declare class PodSecurityPolicy extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html kubernetes_pod_security_policy} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: PodSecurityPolicyConfig);
    /**
     * @stability stable
     */
    get id(): string;
    private _metadata?;
    private __metadataOutput;
    /**
     * @stability stable
     */
    get metadata(): PodSecurityPolicyMetadataOutputReference;
    /**
     * @stability stable
     */
    putMetadata(value: PodSecurityPolicyMetadata): void;
    /**
     * @stability stable
     */
    get metadataInput(): PodSecurityPolicyMetadata | undefined;
    private _spec?;
    private __specOutput;
    /**
     * @stability stable
     */
    get spec(): PodSecurityPolicySpecOutputReference;
    /**
     * @stability stable
     */
    putSpec(value: PodSecurityPolicySpec): void;
    /**
     * @stability stable
     */
    get specInput(): PodSecurityPolicySpec | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
