import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ServiceConfig extends cdktf.TerraformMetaArguments {
    /**
     * Terraform will wait for the load balancer to have at least 1 endpoint before considering the resource created.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service.html#wait_for_load_balancer Service#wait_for_load_balancer}
     *
     * @stability stable
     */
    readonly waitForLoadBalancer?: boolean | cdktf.IResolvable;
    /**
     * metadata block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service.html#metadata Service#metadata}
     *
     * @stability stable
     */
    readonly metadata: ServiceMetadata;
    /**
     * spec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service.html#spec Service#spec}
     *
     * @stability stable
     */
    readonly spec: ServiceSpec;
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service.html#timeouts Service#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: ServiceTimeouts;
}
/**
 * @stability stable
 */
export declare class ServiceStatusLoadBalancerIngress extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get hostname(): string;
    /**
     * @stability stable
     */
    get ip(): string;
}
/**
 * @stability stable
 */
export declare class ServiceStatusLoadBalancer extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get ingress(): any;
}
/**
 * @stability stable
 */
export declare class ServiceStatus extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get loadBalancer(): any;
}
/**
 * @stability stable
 */
export interface ServiceMetadata {
    /**
     * An unstructured key value map stored with the service that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service.html#annotations Service#annotations}
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided.
     *
     * This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service.html#generate_name Service#generate_name}
     *
     * @stability stable
     */
    readonly generateName?: string;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the service.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service.html#labels Service#labels}
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Name of the service, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service.html#name Service#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Namespace defines the space within which name of the service must be unique.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service.html#namespace Service#namespace}
     *
     * @stability stable
     */
    readonly namespace?: string;
}
/**
 * @stability stable
 */
export declare class ServiceMetadataOutputReference extends cdktf.ComplexObject {
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    private _annotations?;
    /**
     * @stability stable
     */
    get annotations(): {
        [key: string]: string;
    } | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    set annotations(value: {
        [key: string]: string;
    } | cdktf.IResolvable | undefined);
    /**
     * @stability stable
     */
    resetAnnotations(): void;
    /**
     * @stability stable
     */
    get annotationsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _generateName?;
    /**
     * @stability stable
     */
    get generateName(): string | undefined;
    /**
     * @stability stable
     */
    set generateName(value: string | undefined);
    /**
     * @stability stable
     */
    resetGenerateName(): void;
    /**
     * @stability stable
     */
    get generateNameInput(): string | undefined;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    } | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    } | cdktf.IResolvable | undefined);
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string | undefined;
    /**
     * @stability stable
     */
    set name(value: string | undefined);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namespace?;
    /**
     * @stability stable
     */
    get namespace(): string | undefined;
    /**
     * @stability stable
     */
    set namespace(value: string | undefined);
    /**
     * @stability stable
     */
    resetNamespace(): void;
    /**
     * @stability stable
     */
    get namespaceInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface ServiceSpecPort {
    /**
     * The name of this port within the service.
     *
     * All ports within the service must have unique names. Optional if only one ServicePort is defined on this service.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service.html#name Service#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The port on each node on which this service is exposed when `type` is `NodePort` or `LoadBalancer`.
     *
     * Usually assigned by the system. If specified, it will be allocated to the service if unused or else creation of the service will fail. Default is to auto-allocate a port if the `type` of this service requires one. More info: http://kubernetes.io/docs/user-guide/services#type--nodeport
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service.html#node_port Service#node_port}
     *
     * @stability stable
     */
    readonly nodePort?: number;
    /**
     * The port that will be exposed by this service.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service.html#port Service#port}
     *
     * @stability stable
     */
    readonly port: number;
    /**
     * The IP protocol for this port. Supports `TCP` and `UDP`. Default is `TCP`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service.html#protocol Service#protocol}
     *
     * @stability stable
     */
    readonly protocol?: string;
    /**
     * Number or name of the port to access on the pods targeted by the service.
     *
     * Number must be in the range 1 to 65535. This field is ignored for services with `cluster_ip = "None"`. More info: http://kubernetes.io/docs/user-guide/services#defining-a-service
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service.html#target_port Service#target_port}
     *
     * @stability stable
     */
    readonly targetPort?: string;
}
/**
 * @stability stable
 */
export interface ServiceSpec {
    /**
     * The IP address of the service.
     *
     * It is usually assigned randomly by the master. If an address is specified manually and is not in use by others, it will be allocated to the service; otherwise, creation of the service will fail. `None` can be specified for headless services when proxying is not required. Ignored if type is `ExternalName`. More info: http://kubernetes.io/docs/user-guide/services#virtual-ips-and-service-proxies
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service.html#cluster_ip Service#cluster_ip}
     *
     * @stability stable
     */
    readonly clusterIp?: string;
    /**
     * A list of IP addresses for which nodes in the cluster will also accept traffic for this service.
     *
     * These IPs are not managed by Kubernetes. The user is responsible for ensuring that traffic arrives at a node with this IP.  A common example is external load-balancers that are not part of the Kubernetes system.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service.html#external_ips Service#external_ips}
     *
     * @stability stable
     */
    readonly externalIps?: string[];
    /**
     * The external reference that kubedns or equivalent will return as a CNAME record for this service.
     *
     * No proxying will be involved. Must be a valid DNS name and requires `type` to be `ExternalName`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service.html#external_name Service#external_name}
     *
     * @stability stable
     */
    readonly externalName?: string;
    /**
     * Denotes if this Service desires to route external traffic to node-local or cluster-wide endpoints.
     *
     * `Local` preserves the client source IP and avoids a second hop for LoadBalancer and Nodeport type services, but risks potentially imbalanced traffic spreading. `Cluster` obscures the client source IP and may cause a second hop to another node, but should have good overall load-spreading. More info: https://kubernetes.io/docs/tutorials/services/source-ip/
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service.html#external_traffic_policy Service#external_traffic_policy}
     *
     * @stability stable
     */
    readonly externalTrafficPolicy?: string;
    /**
     * Specifies the Healthcheck NodePort for the service.
     *
     * Only effects when type is set to `LoadBalancer` and external_traffic_policy is set to `Local`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service.html#health_check_node_port Service#health_check_node_port}
     *
     * @stability stable
     */
    readonly healthCheckNodePort?: number;
    /**
     * Only applies to `type = LoadBalancer`.
     *
     * LoadBalancer will get created with the IP specified in this field. This feature depends on whether the underlying cloud-provider supports specifying this field when a load balancer is created. This field will be ignored if the cloud-provider does not support the feature.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service.html#load_balancer_ip Service#load_balancer_ip}
     *
     * @stability stable
     */
    readonly loadBalancerIp?: string;
    /**
     * If specified and supported by the platform, this will restrict traffic through the cloud-provider load-balancer will be restricted to the specified client IPs.
     *
     * This field will be ignored if the cloud-provider does not support the feature. More info: http://kubernetes.io/docs/user-guide/services-firewalls
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service.html#load_balancer_source_ranges Service#load_balancer_source_ranges}
     *
     * @stability stable
     */
    readonly loadBalancerSourceRanges?: string[];
    /**
     * When set to true, indicates that DNS implementations must publish the `notReadyAddresses` of subsets for the Endpoints associated with the Service.
     *
     * The default value is `false`. The primary use case for setting this field is to use a StatefulSet's Headless Service to propagate `SRV` records for its Pods without respect to their readiness for purpose of peer discovery.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service.html#publish_not_ready_addresses Service#publish_not_ready_addresses}
     *
     * @stability stable
     */
    readonly publishNotReadyAddresses?: boolean | cdktf.IResolvable;
    /**
     * Route service traffic to pods with label keys and values matching this selector.
     *
     * Only applies to types `ClusterIP`, `NodePort`, and `LoadBalancer`. More info: http://kubernetes.io/docs/user-guide/services#overview
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service.html#selector Service#selector}
     *
     * @stability stable
     */
    readonly selector?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Used to maintain session affinity. Supports `ClientIP` and `None`. Defaults to `None`. More info: http://kubernetes.io/docs/user-guide/services#virtual-ips-and-service-proxies.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service.html#session_affinity Service#session_affinity}
     *
     * @stability stable
     */
    readonly sessionAffinity?: string;
    /**
     * Determines how the service is exposed.
     *
     * Defaults to `ClusterIP`. Valid options are `ExternalName`, `ClusterIP`, `NodePort`, and `LoadBalancer`. `ExternalName` maps to the specified `external_name`. More info: http://kubernetes.io/docs/user-guide/services#overview
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service.html#type Service#type}
     *
     * @stability stable
     */
    readonly type?: string;
    /**
     * port block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service.html#port Service#port}
     *
     * @stability stable
     */
    readonly port?: ServiceSpecPort[];
}
/**
 * @stability stable
 */
export declare class ServiceSpecOutputReference extends cdktf.ComplexObject {
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    private _clusterIp?;
    /**
     * @stability stable
     */
    get clusterIp(): string | undefined;
    /**
     * @stability stable
     */
    set clusterIp(value: string | undefined);
    /**
     * @stability stable
     */
    resetClusterIp(): void;
    /**
     * @stability stable
     */
    get clusterIpInput(): string | undefined;
    private _externalIps?;
    /**
     * @stability stable
     */
    get externalIps(): string[] | undefined;
    /**
     * @stability stable
     */
    set externalIps(value: string[] | undefined);
    /**
     * @stability stable
     */
    resetExternalIps(): void;
    /**
     * @stability stable
     */
    get externalIpsInput(): string[] | undefined;
    private _externalName?;
    /**
     * @stability stable
     */
    get externalName(): string | undefined;
    /**
     * @stability stable
     */
    set externalName(value: string | undefined);
    /**
     * @stability stable
     */
    resetExternalName(): void;
    /**
     * @stability stable
     */
    get externalNameInput(): string | undefined;
    private _externalTrafficPolicy?;
    /**
     * @stability stable
     */
    get externalTrafficPolicy(): string | undefined;
    /**
     * @stability stable
     */
    set externalTrafficPolicy(value: string | undefined);
    /**
     * @stability stable
     */
    resetExternalTrafficPolicy(): void;
    /**
     * @stability stable
     */
    get externalTrafficPolicyInput(): string | undefined;
    private _healthCheckNodePort?;
    /**
     * @stability stable
     */
    get healthCheckNodePort(): number | undefined;
    /**
     * @stability stable
     */
    set healthCheckNodePort(value: number | undefined);
    /**
     * @stability stable
     */
    resetHealthCheckNodePort(): void;
    /**
     * @stability stable
     */
    get healthCheckNodePortInput(): number | undefined;
    private _loadBalancerIp?;
    /**
     * @stability stable
     */
    get loadBalancerIp(): string | undefined;
    /**
     * @stability stable
     */
    set loadBalancerIp(value: string | undefined);
    /**
     * @stability stable
     */
    resetLoadBalancerIp(): void;
    /**
     * @stability stable
     */
    get loadBalancerIpInput(): string | undefined;
    private _loadBalancerSourceRanges?;
    /**
     * @stability stable
     */
    get loadBalancerSourceRanges(): string[] | undefined;
    /**
     * @stability stable
     */
    set loadBalancerSourceRanges(value: string[] | undefined);
    /**
     * @stability stable
     */
    resetLoadBalancerSourceRanges(): void;
    /**
     * @stability stable
     */
    get loadBalancerSourceRangesInput(): string[] | undefined;
    private _publishNotReadyAddresses?;
    /**
     * @stability stable
     */
    get publishNotReadyAddresses(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    set publishNotReadyAddresses(value: boolean | cdktf.IResolvable | undefined);
    /**
     * @stability stable
     */
    resetPublishNotReadyAddresses(): void;
    /**
     * @stability stable
     */
    get publishNotReadyAddressesInput(): boolean | cdktf.IResolvable | undefined;
    private _selector?;
    /**
     * @stability stable
     */
    get selector(): {
        [key: string]: string;
    } | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    set selector(value: {
        [key: string]: string;
    } | cdktf.IResolvable | undefined);
    /**
     * @stability stable
     */
    resetSelector(): void;
    /**
     * @stability stable
     */
    get selectorInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _sessionAffinity?;
    /**
     * @stability stable
     */
    get sessionAffinity(): string | undefined;
    /**
     * @stability stable
     */
    set sessionAffinity(value: string | undefined);
    /**
     * @stability stable
     */
    resetSessionAffinity(): void;
    /**
     * @stability stable
     */
    get sessionAffinityInput(): string | undefined;
    private _type?;
    /**
     * @stability stable
     */
    get type(): string | undefined;
    /**
     * @stability stable
     */
    set type(value: string | undefined);
    /**
     * @stability stable
     */
    resetType(): void;
    /**
     * @stability stable
     */
    get typeInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): ServiceSpecPort[] | undefined;
    /**
     * @stability stable
     */
    set port(value: ServiceSpecPort[] | undefined);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): ServiceSpecPort[] | undefined;
}
/**
 * @stability stable
 */
export interface ServiceTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/service.html#create Service#create}.
     *
     * @stability stable
     */
    readonly create?: string;
}
/**
 * @stability stable
 */
export declare class ServiceTimeoutsOutputReference extends cdktf.ComplexObject {
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    private _create?;
    /**
     * @stability stable
     */
    get create(): string | undefined;
    /**
     * @stability stable
     */
    set create(value: string | undefined);
    /**
     * @stability stable
     */
    resetCreate(): void;
    /**
     * @stability stable
     */
    get createInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/kubernetes/r/service.html kubernetes_service}.
 *
 * @stability stable
 */
export declare class Service extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/kubernetes/r/service.html kubernetes_service} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ServiceConfig);
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    status(index: string): ServiceStatus;
    private _waitForLoadBalancer?;
    /**
     * @stability stable
     */
    get waitForLoadBalancer(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    set waitForLoadBalancer(value: boolean | cdktf.IResolvable | undefined);
    /**
     * @stability stable
     */
    resetWaitForLoadBalancer(): void;
    /**
     * @stability stable
     */
    get waitForLoadBalancerInput(): boolean | cdktf.IResolvable | undefined;
    private _metadata?;
    private __metadataOutput;
    /**
     * @stability stable
     */
    get metadata(): ServiceMetadataOutputReference;
    /**
     * @stability stable
     */
    putMetadata(value: ServiceMetadata): void;
    /**
     * @stability stable
     */
    get metadataInput(): ServiceMetadata | undefined;
    private _spec?;
    private __specOutput;
    /**
     * @stability stable
     */
    get spec(): ServiceSpecOutputReference;
    /**
     * @stability stable
     */
    putSpec(value: ServiceSpec): void;
    /**
     * @stability stable
     */
    get specInput(): ServiceSpec | undefined;
    private _timeouts?;
    private __timeoutsOutput;
    /**
     * @stability stable
     */
    get timeouts(): ServiceTimeoutsOutputReference;
    /**
     * @stability stable
     */
    putTimeouts(value: ServiceTimeouts | undefined): void;
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): ServiceTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
