import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface StorageClassConfig extends cdktf.TerraformMetaArguments {
    /**
     * Indicates whether the storage class allow volume expand.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/storage_class.html#allow_volume_expansion StorageClass#allow_volume_expansion}
     *
     * @stability stable
     */
    readonly allowVolumeExpansion?: boolean | cdktf.IResolvable;
    /**
     * Persistent Volumes that are dynamically created by a storage class will have the mount options specified.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/storage_class.html#mount_options StorageClass#mount_options}
     *
     * @stability stable
     */
    readonly mountOptions?: string[];
    /**
     * The parameters for the provisioner that should create volumes of this storage class.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/storage_class.html#parameters StorageClass#parameters}
     *
     * @stability stable
     */
    readonly parameters?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Indicates the type of the reclaim policy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/storage_class.html#reclaim_policy StorageClass#reclaim_policy}
     *
     * @stability stable
     */
    readonly reclaimPolicy?: string;
    /**
     * Indicates the type of the provisioner.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/storage_class.html#storage_provisioner StorageClass#storage_provisioner}
     *
     * @stability stable
     */
    readonly storageProvisioner: string;
    /**
     * Indicates when volume binding and dynamic provisioning should occur.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/storage_class.html#volume_binding_mode StorageClass#volume_binding_mode}
     *
     * @stability stable
     */
    readonly volumeBindingMode?: string;
    /**
     * allowed_topologies block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/storage_class.html#allowed_topologies StorageClass#allowed_topologies}
     *
     * @stability stable
     */
    readonly allowedTopologies?: StorageClassAllowedTopologies;
    /**
     * metadata block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/storage_class.html#metadata StorageClass#metadata}
     *
     * @stability stable
     */
    readonly metadata: StorageClassMetadata;
}
/**
 * @stability stable
 */
export interface StorageClassAllowedTopologiesMatchLabelExpressions {
    /**
     * The label key that the selector applies to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/storage_class.html#key StorageClass#key}
     *
     * @stability stable
     */
    readonly key?: string;
    /**
     * An array of string values. One value must match the label to be selected.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/storage_class.html#values StorageClass#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
/**
 * @stability stable
 */
export interface StorageClassAllowedTopologies {
    /**
     * match_label_expressions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/storage_class.html#match_label_expressions StorageClass#match_label_expressions}
     *
     * @stability stable
     */
    readonly matchLabelExpressions?: StorageClassAllowedTopologiesMatchLabelExpressions[];
}
/**
 * @stability stable
 */
export declare class StorageClassAllowedTopologiesOutputReference extends cdktf.ComplexObject {
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    private _matchLabelExpressions?;
    /**
     * @stability stable
     */
    get matchLabelExpressions(): StorageClassAllowedTopologiesMatchLabelExpressions[] | undefined;
    /**
     * @stability stable
     */
    set matchLabelExpressions(value: StorageClassAllowedTopologiesMatchLabelExpressions[] | undefined);
    /**
     * @stability stable
     */
    resetMatchLabelExpressions(): void;
    /**
     * @stability stable
     */
    get matchLabelExpressionsInput(): StorageClassAllowedTopologiesMatchLabelExpressions[] | undefined;
}
/**
 * @stability stable
 */
export interface StorageClassMetadata {
    /**
     * An unstructured key value map stored with the storage class that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/storage_class.html#annotations StorageClass#annotations}
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided.
     *
     * This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/storage_class.html#generate_name StorageClass#generate_name}
     *
     * @stability stable
     */
    readonly generateName?: string;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the storage class.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/storage_class.html#labels StorageClass#labels}
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Name of the storage class, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/storage_class.html#name StorageClass#name}
     *
     * @stability stable
     */
    readonly name?: string;
}
/**
 * @stability stable
 */
export declare class StorageClassMetadataOutputReference extends cdktf.ComplexObject {
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    private _annotations?;
    /**
     * @stability stable
     */
    get annotations(): {
        [key: string]: string;
    } | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    set annotations(value: {
        [key: string]: string;
    } | cdktf.IResolvable | undefined);
    /**
     * @stability stable
     */
    resetAnnotations(): void;
    /**
     * @stability stable
     */
    get annotationsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _generateName?;
    /**
     * @stability stable
     */
    get generateName(): string | undefined;
    /**
     * @stability stable
     */
    set generateName(value: string | undefined);
    /**
     * @stability stable
     */
    resetGenerateName(): void;
    /**
     * @stability stable
     */
    get generateNameInput(): string | undefined;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    } | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    } | cdktf.IResolvable | undefined);
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string | undefined;
    /**
     * @stability stable
     */
    set name(value: string | undefined);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/kubernetes/r/storage_class.html kubernetes_storage_class}.
 *
 * @stability stable
 */
export declare class StorageClass extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/kubernetes/r/storage_class.html kubernetes_storage_class} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: StorageClassConfig);
    private _allowVolumeExpansion?;
    /**
     * @stability stable
     */
    get allowVolumeExpansion(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    set allowVolumeExpansion(value: boolean | cdktf.IResolvable | undefined);
    /**
     * @stability stable
     */
    resetAllowVolumeExpansion(): void;
    /**
     * @stability stable
     */
    get allowVolumeExpansionInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _mountOptions?;
    /**
     * @stability stable
     */
    get mountOptions(): string[] | undefined;
    /**
     * @stability stable
     */
    set mountOptions(value: string[] | undefined);
    /**
     * @stability stable
     */
    resetMountOptions(): void;
    /**
     * @stability stable
     */
    get mountOptionsInput(): string[] | undefined;
    private _parameters?;
    /**
     * @stability stable
     */
    get parameters(): {
        [key: string]: string;
    } | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    set parameters(value: {
        [key: string]: string;
    } | cdktf.IResolvable | undefined);
    /**
     * @stability stable
     */
    resetParameters(): void;
    /**
     * @stability stable
     */
    get parametersInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _reclaimPolicy?;
    /**
     * @stability stable
     */
    get reclaimPolicy(): string | undefined;
    /**
     * @stability stable
     */
    set reclaimPolicy(value: string | undefined);
    /**
     * @stability stable
     */
    resetReclaimPolicy(): void;
    /**
     * @stability stable
     */
    get reclaimPolicyInput(): string | undefined;
    private _storageProvisioner?;
    /**
     * @stability stable
     */
    get storageProvisioner(): string;
    /**
     * @stability stable
     */
    set storageProvisioner(value: string);
    /**
     * @stability stable
     */
    get storageProvisionerInput(): string | undefined;
    private _volumeBindingMode?;
    /**
     * @stability stable
     */
    get volumeBindingMode(): string | undefined;
    /**
     * @stability stable
     */
    set volumeBindingMode(value: string | undefined);
    /**
     * @stability stable
     */
    resetVolumeBindingMode(): void;
    /**
     * @stability stable
     */
    get volumeBindingModeInput(): string | undefined;
    private _allowedTopologies?;
    private __allowedTopologiesOutput;
    /**
     * @stability stable
     */
    get allowedTopologies(): StorageClassAllowedTopologiesOutputReference;
    /**
     * @stability stable
     */
    putAllowedTopologies(value: StorageClassAllowedTopologies | undefined): void;
    /**
     * @stability stable
     */
    resetAllowedTopologies(): void;
    /**
     * @stability stable
     */
    get allowedTopologiesInput(): StorageClassAllowedTopologies | undefined;
    private _metadata?;
    private __metadataOutput;
    /**
     * @stability stable
     */
    get metadata(): StorageClassMetadataOutputReference;
    /**
     * @stability stable
     */
    putMetadata(value: StorageClassMetadata): void;
    /**
     * @stability stable
     */
    get metadataInput(): StorageClassMetadata | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
